@@ -4,6 +4,6 @@ file __init__.py
 
 '''
 
-import geocode.paser
+import geocode
 
 Readboundry = geocode.paser.Readboundry
